/*

	Zen Photo Admin
	
*/
/* Basics
------------------------------ */
html { /* Force vertical scrollbar to prevent page shift "jog" */
	/* IE */
	overflow-y: scroll;
	/* Moz */
	height: 100%;
	margin-bottom: 0.1em;
}

body {
	font: normal 82% "Helvetica Neue", Helvetica, Arial, sans-serif;
	color: #5A5A4B;
	text-align: center;
	background: #D0DBDF;
	margin: 0;
	padding: 0;
}

/* Main Layout
------------------------------ */
#logo {
	float: left;
	text-align: left;
	margin: 20px 10px 0px 30px;
	width: 200px;
	height: 47px;
}

#logo img {
	border: 0;
}

#main {
	text-align: left;
	padding: 20px 0;
	clear: both;
}

#footer {
	clear: both;
	color: #597580;
	font-size: 85%;
	margin: 8px 30px 0px;
	text-align: right;
}

#footer a {
	color: #597580;
	text-decoration: none;
	border-bottom: 1px dotted #597580;
}

#footer a:hover {
	color: #4B636B;
	text-decoration: none;
	border-bottom: 1px solid #4B636B;
}

#links {
	float: right;
	font-size: 100%;
	margin: 40px 30px 0 0;
}

#links a {
	color: #597580;
	text-decoration: none;
	border-bottom: 1px dotted #597580;
}

#links a:hover {
	color: #4B636B;
	text-decoration: none;
	border-bottom: 1px solid #4B636B;
}

#content {
	padding: 30px;
	background-color: #fff;
	border-top: 1px solid #BAC9CF;
	border-bottom: 5px solid #BAC9CF;
	min-height: 450px;
	_height: 450px; /* IE Only */
}

/* Text Styles
------------------------------ */
h1 {
	color: #000;
	font-size: 136%;
	font-weight: normal;
	margin: 0px 0px 20px 0px;
}

h2 {
	font-size: 100%;
	font-weight: bold;
	margin: 0px 0px 5px 0px;
}

h2.h2_bordered {
	font-weight: bold;
	padding: 4px 12px;
	border-bottom: 2px solid #BAC9CF; 
	background: #ECF1F2;
	}

/* edit page subheadlines like "images" or "albums" */
.subheadline {
	color: #000;
	font-size: 136%;
	font-weight: normal;
	margin: 0px 0px 0px 0px;
}

h3 {
	font-size: 100%;
	font-weight: normal;
	margin: 0px 0px 5px 0px;
}

p {
	line-height: 1.2em;
	margin-bottom: 0.8em;
}

/* Menu
------------------------------ */
.nav {
	list-style-type: none;
	padding: 0;
	_padding: 0 0 0 30px;
	margin: 0 0 0 30px;
	height: 30px;
	width: 95%;
}

.nav li {
	display: inline;
}

.nav li a {
	border-top: 1px solid #C7D3D8;
	border-left: 1px solid #C7D3D8;
	border-right: 1px solid #C7D3D8;
	font-size: 115%;
	display: block;
	float: left;
	padding: 6px 12px;
	margin: 0px 8px 0px 0px;
	text-decoration: none;
	font-weight: normal;
	height: 17px;
	color: #8797A5;
	background: #E9ECEF;
	_position: relative; /* IE Only */
	_top: 6px; /* IE Only */
}

.nav li a:hover {
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	color: #000;
	background-color: #F7F8F9;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

.nav li.current a {
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	color: #4D646F;
	background-color: #fff;
	cursor: default;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

.nav li.currentsubtab a {
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	color: #4D646F;
	background-color: #F7F8F9;
	cursor: default;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

.nav li. a:hover {
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	color: #000;
	background-color: #F7F8F9;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

.subnav {
	list-style-type: none;
	padding: 0;
	_padding: 0 0 0 30px;
	margin: 0 0 0 30px;
	height: 30px;
	width: 95%;
}

.subnav li {
	display: inline;
}

.subnav li a {
	border-top: 1px solid #C7D3D8;
	border-left: 1px solid #C7D3D8;
	border-right: 1px solid #C7D3D8;
	font-size: 115%;
	display: block;
	float: left;
	padding: 6px 12px;
	margin: 0px 8px 0px 0px;
	text-decoration: none;
	font-weight: normal;
	height: 17px;
	color: #8797A5;
	background: #E9ECEF;
	_position: relative; /* IE Only */
	_top: 6px; /* IE Only */
}

.subnav li a:hover {
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	color: #000;
	background-color: #F7F6F8;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

.subnav li.current a {
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	color: #4D646F;
	background-color: #F7F8F9;
	cursor: default;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

.subnav li. a:hover {
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	color: #000;
	background-color: #F7F8F9;
	height: 21px;
	_height: 24px;
	position: relative;
	top: -3px;
	_top: 1px; /* IE Only */
}

/* Messages 
------------------------------ */
.messagebox {
	padding: 20px;
	background-color: #B1F7B6;
	border: 1px solid #009966;
	border-bottom: 5px solid #009966;
	margin-bottom: 10px;
}

.messagebox h2 {
	color: #006633;
	font-size: 100%;
	font-weight: bold;
	margin: 0px;
}

/* Error Messages
------------------------------ */
.errorbox {
	padding: 20px;
	background-color: #FDD;
	border-top: 1px solid #FAA;
	border-left: 1px solid #FAA;
	border-right: 1px solid #FAA;
	border-bottom: 5px solid #FAA;
	margin-bottom: 10px;
	font-size: 100%;
}

.errorbox h2 {
	color: #DD6666;
	font-size: 100%;
	font-weight: bold;
	margin: 0px;
}

/* Warning Messages
------------------------------ */
.warningbox {
	padding: 20px;
	background-color: #FFFF00;
	border-top: 1px solid #996600;
	border-left: 1px solid #996600;
	border-right: 1px solid #996600;
	border-bottom: 5px solid #996600;
	margin-bottom: 10px;
	font-size: 100%;
}

.warningbox h2 {
	color: #663300;
	font-size: 100%;
	font-weight: bold;
	margin: 0px;
}

/* Miscellaneous
------------------------------ */
a {
	color: #4D76CF;
	text-decoration: none;
}

a img {
	border-width: 1px;
}

a:hover {
	color: #FF8A00;
}

hr {
	height: 0px;
	border: 0px;
	border-bottom: 1px solid #BAC9CF;
	margin: 1em 0px;
}

table.noinput {
	width: 100%;
	padding: 0px;
	border-spacing: 1px;
	background: #F1F2F3;
	border: 1px solid #BAC9CF;
}

table.noinput td {
	font-weight: normal;
	font-family: Arial, Helvetica, sans-serif;
	font-size: 110%
}

table.bordered {
	width: 100%;
	padding: 0px;
	border-spacing: 1px;
	background: #F1F2F3;
	border: 1px solid #BAC9CF;
	border-bottom-width: 5px;
}

table.bordered th {
	font-weight: normal;
	padding: 4px 12px;
	border-bottom: 2px solid #BAC9CF; 
	background: #ECF1F2;
}

table.bordered .subhead {
	border-top: 1px solid #BAC9CF;
}

table.bordered td {
	padding: 8px 16px;
	margin: 0px;
	background-color: #fff;
}

table.bordered tr.alt td {
	background-color: #f0f0f0;
}

table.bordered tr.alt1 td {
	background-color: #ECF1F2;
	border-bottom: 2px solid #BAC9CF; 
}


table.formlayout td {
	padding: 2px;
	vertical-align: top;
}

table.checkboxes {
	padding: 0px;
	margin: 0px;
	line-height: 10px;
	border: 0px;
}

table.checkboxes tr {
	padding: 0px;
	margin: 0px;
	height: 18px;
}

table.checkboxes td {
	padding: 0px 12px 0px 0px;
	margin: 0px;
}

.box {
	padding: 0;
	background: #F7F8F9;
	border: 1px solid #BAC9CF;
	border-bottom-width: 5px;
}

.innerbox {
	background: #fff;
	border: 1px solid #BAC9CF;
	border-bottom-width: 5px;
}

.imagethumb {
	margin: 1px;
	padding: 1px;
}

/* Sortable Images
------------------------------ */
div.ui-sortable img {
	float:left;
}

div.ui-sortable {
	clear:both;
	overflow:hidden;
}

/* Sortable Album Divs
------------------------------ */
div.albumList {
	list-style-type: none;
	padding: 0px;
	margin: 0px;
}

div.albumList div {
	margin: 2px 2px;
	border: 1px solid #F0F3F8;
}

td.handle {
	cursor: move;
}

/* Sortable placeholder
------------------------------ */

html>/**/body .zensortable_row, html>/**/body .zensortable_img {
	background:#CFF1FF;
	float:left;
	margin:1px;
	padding:0px;
	border:1px solid #ff5 !important;
	border:0px;
	color:#ff8;
}

.zensortable_img {
	width:85px;
	height:85px;
}

.zensortable_row {
	width:100%;
	height:60px;
}

/* Forms
------------------------------ */
input {
	font-family: Arial, Helvetica, sans-serif;
	font-size: 100%;
}

textarea {
	font-family: Arial, Helvetica, sans-serif;
	font-size: 100%;
}

input.tags {
	width: 408px;
}

/* Individual Page Styles
------------------------------ */
#home-actions {
	list-style-type: none;
	margin: 0px 0px 0px 10px;
	padding: 0px;
}

#home-actions li {
	margin-bottom: 3px;
	font-size: 100%;
}

#overview-leftcolumn {
	border:0px solid gray;
	width: 45%;
	float: left;
}

#overview-rightcolumn {
	border:0px solid gray;
	width: 50%;
	float: left;
}
#overview-stats {
	float:left;
	width: 400px;
	margin: 0 0 10px 10px;
	padding: 0px;
}



#overview-maint {
	float:left;
	width: 480px;
	margin: 0 0 10px 0px;
	padding: 0px;
}
#overview-maint_l {
	float:left;
	width: 50%;
	margin: 5px 0px 0px 8px;

}
#overview-maint_r {
	float:left;
	width: 45%;
	margin: 5px 0px 0px 0px;
}

	
#overview-comments {
	float:left;
	width: 90%;
	margin: 0 0 10px 10px;
	padding: 0px;
}

#overview-comments h3 {
	font-weight: bold;
	padding-left: 10px;
	margin: 0;
	}

#overview-comments ul, #overview-maint ul, #overview-stats ul {
	width: 450px; 
	list-style-type: none;
	padding: 10px;
}

#overview-comments ul li, #overview-maint ul li{
	margin-bottom: .5em;
}

#overview-comments ul.plugins {
	width: 450px; 
	list-style-type: none;
	padding: 0px 0px 10px 10px;
	}


#overview-comments ul.plugins li {
	margin-left: 1em;
	margin-bottom: 0em;
	}

#overview-comments ul.filters {
	width: 450px; 
	list-style-type: none;
	padding: 0;
	}


#overview-comments ul.filters li {
	margin-left: 1em;
	margin-bottom: 0em;
	}

#overview-comments .commentmeta {
	font-size: 85%;
	color: #999;
}

#overview-comments .commentbody {
	font-size: 85%;
}

.fileuploadbox {
	margin-bottom: 5px;
}

#albumselect {
	padding: 10px;
	background: #F7F8F9;
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	border-bottom: 5px solid #BAC9CF;
}

#albumselect input {
	padding: 4px;
	font-weight: normal;
	font-size: 100%;
}

.theme_links {
	list-style: none;
}

.theme_links li {
	padding-bottom: 10px;
}

#theme-editor #files {
	float:right;
	border:1px solid #BAC9CF;
	background:#ECF1F2;
	width:200px;
}

#theme-editor #files ul {
	list-style-type:none;
	padding:5px;
	margin-bottom:5px;
}

#theme-editor #editor {
	margin-right:210px;
	background:#ECF1F2;
	background:#F7F8F9;
}

#theme-editor #editor form {
	padding:5px;
}

#theme-editor #editor textarea {
	font-family:Consolas,Monaco,Courier,monospace;
	font-size:12px;
	width:99%;
	padding:3px;
}

acronym {
	cursor: help;
}

/* Login
------------------------------ */
#loginform {
	padding: 10px;
	width: 300px;
	margin: 25px auto;
	font-size: 100%;
	background: #F7F8F9;
	border-top: 1px solid #BAC9CF;
	border-left: 1px solid #BAC9CF;
	border-right: 1px solid #BAC9CF;
	border-bottom: 5px solid #BAC9CF;
}

.button {
	cursor: pointer;
	padding: 5px 10px;
}

label {
	cursor: pointer;
}

label:hover {
	color: #000;
}

#loginform input.textfield {
	margin: 0px;
	font-size: 100%;
	padding: 4px;
}

#loginform table {
	margin: 0px auto;
	border: 0px;
}

#loginform td {
	padding: 4px;
}

/* Thumbnail Preview selectbox effect.
------------------------------------- */
.thumbselect {
	padding-left: 90px;
	background-repeat: no-repeat;
	background-position: center left;
	height: 90px;
}

.thumboption {
	padding-left: 90px;
	height: 40px;
	margin-bottom: 2px;
	background-position: center left;
}

/* Option Tabs
-------------------------------------*/
.space {
	margin-top: 40px;
}

.ui-tabs-hide {
	display: none;
}

.ui-tabs-nav {
	list-style: none;
	padding: 0;
	margin: 0;
	height: 17px;
}

.ui-tabs-nav li {
	float: left;
}

.ui-tabs-nav a {
	float: left;
	padding: 6px 12px;
	margin: 0px 10px 0px 0px;
	text-decoration: none;
	color: #6b7d84;
	outline: none;
	background: #E9ECEF;
	border-top: 1px solid #C7D3D8;
	border-left: 1px solid #C7D3D8;
	border-right: 1px solid #C7D3D8;
}

.ui-tabs-nav a:hover {
	background-color: #d6dbde;
}

.ui-tabs-nav .ui-tabs-selected a {
	background-color: #d6dbde;
	border-top: 3px solid #6b7d84;
	padding-top: 4px;
	color: #6b7d84;
}

.ui-tabs-disabled {
	
}

.ui-tabs-panel {
	padding: 1em 0px;
	background: #fff;
	/* declare background color for container to avoid distorted fonts in IE while fading */
}

/* Additional IE specific bug fixes... */
* html .ui-tabs-nav { /* auto clear, @ IE 6 & IE 7 Quirks Mode */
	display: inline-block;
}

* :first-child+html .ui-tabs-nav {
	/* @ IE 7 Standards Mode - do not group selectors, otherwise IE 6 will ignore complete rule (because of the unknown + combinator)... */
	display: inline-block;
}

/* Pretty Buttons
------------------------------------- */
.buttons a,.buttons button {
	display: block;
	float: left;
	margin: 0 7px 0 0;
	background-color: #f5f5f5;
	border: 1px solid #dedede;
	border-top: 1px solid #eee;
	border-left: 1px solid #eee;
	font-family: "Lucida Grande", Tahoma, Arial, Verdana, sans-serif;
	font-size: 100%;
	line-height: 130%;
	text-decoration: none;
	font-weight: bold;
	color: #565656;
	cursor: pointer;
	padding: 5px 10px 6px 7px; /* Links */
}

.buttons button {
	text-decoration: none;
	width: auto;
	overflow: visible;
	padding: 4px 10px 3px 7px; /* IE6 */
}

.buttons button[type] {
	text-decoration: none;
	padding: 5px 10px 5px 7px; /* Firefox */
	line-height: 17px; /* Safari */
}

.buttons button img,.buttons a img {
	text-decoration: none;
	margin: 0 3px -3px 0 !important;
	padding: 0;
	border: none;
	width: 16px;
	height: 16px;
}

/* standard buttons */
button:hover,.buttons a:hover {
	text-decoration: none;
	background-color: #dff4ff;
	border: 1px solid #c2e1ef;
	color: #336699;
}

.buttons a:active {
	text-decoration: none;
	background-color: #6299c5;
	border: 1px solid #6299c5;
	color: #fff;
}

/* positive buttons */
button.positive,.buttons a.positive {
	text-decoration: none;
	color: #529214;
}

.buttons a.positive:hover,button.positive:hover {
	text-decoration: none;
	background-color: #E6EFC2;
	border: 1px solid #C6D880;
	color: #529214;
}

.buttons a.positive:active {
	text-decoration: none;
	background-color: #529214;
	border: 1px solid #529214;
	color: #fff;
}

/* negative buttons */
.buttons a.negative,button.negative {
	text-decoration: none;
	color: #d12f19;
}

.buttons a.negative:hover,button.negative:hover {
	text-decoration: none;
	background: #fbe3e4;
	border: 1px solid #fbc2c4;
	color: #d12f19;
}

.buttons a.negative:active {
	text-decoration: none;
	background-color: #d12f19;
	border: 1px solid #d12f19;
	color: #fff;
}

.buttons .tooltip {
	width: 17em;
	text-align: left;
}

#tooltip {
	position: absolute;
	z-index: 3000;
	border: 1px solid #dedede;
	background-color: #f5f5f5;
	padding: 5px;
	opacity: 0.85;
	width: 300px;
}

#tooltip h3,#tooltip div {
	margin: 0;
}

/* scrollable checklists 
-----------------------------*/
/* Undo some styles from the master stylesheet */
.tagchecklist li {
	background: none;
	padding-left: 0;
	text-align: left;
	
}

/* CSS for tag checklists */
.tagchecklist hr {
	padding: 0;
	margin-left: 0px;
	margin-right: 0px;
	margin-top: 0px;
	margin-bottom: 0px;
}

.tagchecklist {
	border: 1px solid #ccc;
	list-style: none;
	height: 24em;
	width: 20em;
	overflow: auto;
	background-color: white;
}

.tagchecklist,.tagchecklist li {
	margin: 0;
	padding: 0;
	border-bottom: 1px dotted #BAC9CF;
}

.tagchecklist label {
	display: block;
	padding: 0 0.2em 0 25px;
	text-indent: -25px;
}

.tagchecklist label:hover,.tagchecklist label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .tagchecklist label {
	height: 1%;
}

/* CSS for tag rename lists */
.tagrenamelist {
	border: 1px solid #ccc;
	list-style: none;
	height: 24em;
	width: 19.2em;
	overflow: auto;
	background-color: white;
	padding-left: 4px;
}

.tagrenamelist,.tagrenamelist li {
	margin: 0;
	border-bottom: 1px dotted #BAC9CF;
}

.tagrenamelist label {
	display: block;
}

.tagrenamelist label:hover,.tagrenamelist label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .tagrenamelist label {
	height: 1%;
}

/* CSS for tag new lists 
-----------------------------*/
.tagnewlist {
	border: 1px solid #ccc;
	list-style: none;
	height: 24em;
	width: 19.2em;
	overflow: auto;
	background-color: white;
	padding-left: 4px;
}

.tagnewlist,.tagnewlist li {
	margin: 0;
	border-bottom: 1px dotted #C6D880;
}

.tagnewlist label {
	display: block;
}

.tagnewlist label:hover,.tagnewlist label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .tagnewlist label {
	height: 1%;
}

/* search field checklist */
.searchchecklist {
	border: 1px solid #ccc;
	list-style: none;
	height: 6em;
	width: 310px;
	overflow: auto;
	background-color: white;
}


/* scrollable checklists 
-----------------------------*/
	/* Undo some styles from the master stylesheet */
.albumchecklist li {
	background: none;
	padding-left: 0;
	text-align: left;
	
}

/* CSS for album checklists */
.albumchecklist {
	border: 1px solid #ccc;
	list-style: none;
	height: 8em;
	overflow: auto;
	width: 20em;
	background-color: white;
}

.albumchecklist,.albumchecklist li {
	margin: 0;
	padding: 0;
	border-bottom: 1px dotted #C6D880;
}

.albumchecklist label {
	display: block;
	padding: 0 0.2em 0 25px;
	text-indent: -25px;
}

.albumchecklist label:hover,.albumchecklist label.hover {
	background: #777;
	color: #fff;
}

* html .albumchecklist label {
	height: 1%;
}

.customchecklist li {
	background: none;
	padding-left: 0;
	text-align: left;
	
}

/* CSS for custom checklists */
.customchecklist {
	border: 1px solid #ccc;
	list-style: none;
	height: 8em;
	overflow: auto;
	width: 20em;
	background-color: white;
}

.customchecklist,.customchecklist li {
	margin: 0;
	padding: 0;
	border-bottom: 1px dotted #C6D880;
}

.customchecklist label {
	display: block;
	padding: 0 0.2em 0 25px;
	text-indent: -25px;
}

.customchecklist label:hover,.customchecklist label.hover {
	background: #777;
	color: #fff;
}

* html .customchecklist label {
	height: 1%;
}

/* image pagination on album edit page 
-------------------------------------------*/
#imagenav {
	text-align:center; 
	background: #ECF1F2;
	border-bottom: 2px solid #BAC9CF;
}
#imagenavb {
	text-align:center; 
	background: #ECF1F2;
	border-top: 2px solid #BAC9CF;
}
ul.pagelist {
	clear: both;
	padding: 0;
	margin: 0px;
	list-style-type: none;
}
ul.pagelist li {
	display: inline; }
ul.pagelist li a, ul.pagelist span.disabledlink {
	padding-left: 4px; padding-right: 4px;
}
ul.pagelist li.current {
	font-weight: bold;
	text-decoration: none;
	cursor: default;
	color: black; padding-left: 4px; padding-right: 4px;
}

/* CSS for language_string_list */
.language_string_list {
	border: 1px solid #ccc;
	list-style: none;
	height: 5.5em;
	width: 26em;
	overflow: auto;
	background-color: white;
}

.language_string_list,.language_string_list li {
	margin: 0;
	padding: 0;
	padding-bottom: 5px;
	border-bottom: 1px dotted #C6D880;
}

.language_string_list label {
	display: block;
}

.language_string_list label:hover,.language_string_list label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .language_string_list label {
	height: 1%;
}

/* CSS for language_string_listbox 
--------------------------------------*/
.language_string_listbox {
	border: 1px solid #ccc;
	list-style: none;
	height: 14em;
	width: 26em;
	overflow: auto;
	background-color: white;
}

.language_string_listbox,.language_string_listbox li {
	margin: 0;
	padding: 0;
	padding-bottom: 5px;
	border-bottom: 1px dotted #C6D880;
}

.language_string_listbox label {
	display: block;
}

.language_string_listbox label:hover,.language_string_listbox label.hover {
	background: #F1F2F3;
	color: #333;
}

* html .language_string_listbox label {
	height: 1%;
}

/* icon legend 
------------------*/
.iconlegend {
	
	height: 20px;
	text-align: right;
}

.iconlegend li  {
	display: inline;
	margin-right: 10px;
}

.iconlegend li img {
	position: relative;
	top: 3px;
	margin: 0 2px 0 0;
} 

.jcExample p{
	width: 400px;
}
#administration {
	float:left;
	text-align:left;
	font-size: 2em;
	text-decoration:none;
}
span.tagMatches { 
	width: 165px;
	position: absolute;
	z-index: 100;
	max-height: 300px;
	text-align: left;
	overflow: auto;
	border: 0;
} 
    
span.tagMatches span { 
	color: gray;
	cursor: pointer; 
	width: 150px; 
	background-color: #F5F5F3; 
} 

._tag_suggestion {
	float: left; 
}
