-- MySQL dump 10.11
--
-- Host: localhost    Database: ccccmoor_znp01
-- ------------------------------------------------------
-- Server version	5.0.75-community-log

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `znp_administrators`
--

DROP TABLE IF EXISTS `znp_administrators`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `znp_administrators` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `user` varchar(64) collate utf8_unicode_ci NOT NULL,
  `password` text collate utf8_unicode_ci NOT NULL,
  `name` text collate utf8_unicode_ci,
  `email` text collate utf8_unicode_ci,
  `rights` int(11) default NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `user` (`user`)
) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `znp_administrators`
--

LOCK TABLES `znp_administrators` WRITE;
/*!40000 ALTER TABLE `znp_administrators` DISABLE KEYS */;
INSERT INTO `znp_administrators` VALUES (1,'admin','99b28588b76725a526763ffd50839e28','Your Name','you@yourdomain.com',75614);
/*!40000 ALTER TABLE `znp_administrators` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `znp_admintoalbum`
--

DROP TABLE IF EXISTS `znp_admintoalbum`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `znp_admintoalbum` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `adminid` int(11) unsigned NOT NULL,
  `albumid` int(11) unsigned NOT NULL,
  PRIMARY KEY  (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `znp_admintoalbum`
--

LOCK TABLES `znp_admintoalbum` WRITE;
/*!40000 ALTER TABLE `znp_admintoalbum` DISABLE KEYS */;
/*!40000 ALTER TABLE `znp_admintoalbum` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `znp_albums`
--

DROP TABLE IF EXISTS `znp_albums`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `znp_albums` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `parentid` int(11) unsigned default NULL,
  `folder` varchar(255) collate utf8_unicode_ci NOT NULL default '',
  `title` text collate utf8_unicode_ci,
  `desc` text collate utf8_unicode_ci,
  `date` datetime default NULL,
  `place` text collate utf8_unicode_ci,
  `show` int(1) unsigned NOT NULL default '1',
  `closecomments` int(1) unsigned NOT NULL default '0',
  `commentson` int(1) unsigned NOT NULL default '1',
  `thumb` varchar(255) collate utf8_unicode_ci default NULL,
  `mtime` int(32) default NULL,
  `sort_type` varchar(20) collate utf8_unicode_ci default NULL,
  `subalbum_sort_type` varchar(20) collate utf8_unicode_ci default NULL,
  `sort_order` int(11) unsigned default NULL,
  `image_sortdirection` int(1) unsigned default '0',
  `album_sortdirection` int(1) unsigned default '0',
  `hitcounter` int(11) unsigned default '0',
  `password` varchar(255) collate utf8_unicode_ci NOT NULL default '',
  `password_hint` text collate utf8_unicode_ci,
  `total_value` int(11) unsigned default '0',
  `total_votes` int(11) unsigned default '0',
  `used_ips` longtext collate utf8_unicode_ci,
  `custom_data` text collate utf8_unicode_ci,
  `dynamic` int(1) unsigned default '0',
  `search_params` text collate utf8_unicode_ci,
  `album_theme` text collate utf8_unicode_ci,
  `user` varchar(64) collate utf8_unicode_ci default '',
  PRIMARY KEY  (`id`),
  KEY `folder` (`folder`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `znp_albums`
--

LOCK TABLES `znp_albums` WRITE;
/*!40000 ALTER TABLE `znp_albums` DISABLE KEYS */;
/*!40000 ALTER TABLE `znp_albums` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `znp_captcha`
--

DROP TABLE IF EXISTS `znp_captcha`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `znp_captcha` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `ptime` int(32) unsigned NOT NULL,
  `hash` varchar(255) collate utf8_unicode_ci NOT NULL,
  PRIMARY KEY  (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=8 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `znp_captcha`
--

LOCK TABLES `znp_captcha` WRITE;
/*!40000 ALTER TABLE `znp_captcha` DISABLE KEYS */;
INSERT INTO `znp_captcha` VALUES (7,1232774355,'78aacf7bf4322622882679f4dea450a5');
/*!40000 ALTER TABLE `znp_captcha` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `znp_comments`
--

DROP TABLE IF EXISTS `znp_comments`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `znp_comments` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `ownerid` int(11) unsigned NOT NULL default '0',
  `name` varchar(255) collate utf8_unicode_ci NOT NULL default '',
  `email` varchar(255) collate utf8_unicode_ci NOT NULL default '',
  `website` varchar(255) collate utf8_unicode_ci default NULL,
  `date` datetime default NULL,
  `comment` text collate utf8_unicode_ci NOT NULL,
  `inmoderation` int(1) unsigned NOT NULL default '0',
  `type` varchar(52) collate utf8_unicode_ci NOT NULL default 'images',
  `IP` text collate utf8_unicode_ci,
  `private` int(1) unsigned default '0',
  `anon` int(1) unsigned default '0',
  PRIMARY KEY  (`id`),
  KEY `ownerid` (`ownerid`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `znp_comments`
--

LOCK TABLES `znp_comments` WRITE;
/*!40000 ALTER TABLE `znp_comments` DISABLE KEYS */;
/*!40000 ALTER TABLE `znp_comments` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `znp_images`
--

DROP TABLE IF EXISTS `znp_images`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `znp_images` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `albumid` int(11) unsigned NOT NULL default '0',
  `filename` varchar(255) collate utf8_unicode_ci NOT NULL default '',
  `title` text collate utf8_unicode_ci,
  `desc` text collate utf8_unicode_ci,
  `location` text collate utf8_unicode_ci,
  `city` tinytext collate utf8_unicode_ci,
  `state` tinytext collate utf8_unicode_ci,
  `country` tinytext collate utf8_unicode_ci,
  `credit` text collate utf8_unicode_ci,
  `copyright` text collate utf8_unicode_ci,
  `commentson` int(1) NOT NULL default '1',
  `show` int(1) NOT NULL default '1',
  `date` datetime default NULL,
  `sort_order` int(11) unsigned default NULL,
  `height` int(10) unsigned default NULL,
  `width` int(10) unsigned default NULL,
  `thumbX` int(10) unsigned default NULL,
  `thumbY` int(10) unsigned default NULL,
  `thumbW` int(10) unsigned default NULL,
  `thumbH` int(10) unsigned default NULL,
  `mtime` int(32) default NULL,
  `EXIFValid` int(1) unsigned default NULL,
  `hitcounter` int(11) unsigned default '0',
  `total_value` int(11) unsigned default '0',
  `total_votes` int(11) unsigned default '0',
  `used_ips` longtext collate utf8_unicode_ci,
  `EXIFOrientation` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFMake` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFModel` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFExposureTime` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFFNumber` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFFocalLength` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFFocalLength35mm` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFISOSpeedRatings` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFDateTimeOriginal` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFExposureBiasValue` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFMeteringMode` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFFlash` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFImageWidth` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFImageHeight` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFContrast` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFSharpness` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFSaturation` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFWhiteBalance` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFSubjectDistance` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFGPSLatitude` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFGPSLatitudeRef` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFGPSLongitude` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFGPSLongitudeRef` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFGPSAltitude` varchar(52) collate utf8_unicode_ci default NULL,
  `EXIFGPSAltitudeRef` varchar(52) collate utf8_unicode_ci default NULL,
  `custom_data` text collate utf8_unicode_ci,
  PRIMARY KEY  (`id`),
  KEY `filename` (`filename`,`albumid`),
  KEY `znp_images_ibfk1` (`albumid`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `znp_images`
--

LOCK TABLES `znp_images` WRITE;
/*!40000 ALTER TABLE `znp_images` DISABLE KEYS */;
/*!40000 ALTER TABLE `znp_images` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `znp_obj_to_tag`
--

DROP TABLE IF EXISTS `znp_obj_to_tag`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `znp_obj_to_tag` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `tagid` int(11) unsigned NOT NULL,
  `type` tinytext collate utf8_unicode_ci,
  `objectid` int(11) unsigned NOT NULL,
  PRIMARY KEY  (`id`),
  KEY `tagid` (`tagid`),
  KEY `objectid` (`objectid`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `znp_obj_to_tag`
--

LOCK TABLES `znp_obj_to_tag` WRITE;
/*!40000 ALTER TABLE `znp_obj_to_tag` DISABLE KEYS */;
/*!40000 ALTER TABLE `znp_obj_to_tag` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `znp_options`
--

DROP TABLE IF EXISTS `znp_options`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `znp_options` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `ownerid` int(11) unsigned NOT NULL default '0',
  `name` varchar(255) collate utf8_unicode_ci default NULL,
  `value` text collate utf8_unicode_ci,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_option` (`name`,`ownerid`)
) ENGINE=MyISAM AUTO_INCREMENT=161 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `znp_options`
--

LOCK TABLES `znp_options` WRITE;
/*!40000 ALTER TABLE `znp_options` DISABLE KEYS */;
INSERT INTO `znp_options` VALUES (1,0,'zenphoto_release','3427'),(2,0,'gallery_title','Gallery'),(3,0,'website_title',''),(4,0,'website_url',''),(5,0,'time_offset','0'),(6,0,'mod_rewrite','0'),(7,0,'mod_rewrite_image_suffix','.php'),(8,0,'server_protocol','http'),(9,0,'charset','UTF-8'),(10,0,'image_quality','85'),(11,0,'thumb_quality','75'),(12,0,'image_size','595'),(13,0,'image_use_side','longest'),(14,0,'image_allow_upscale','0'),(15,0,'thumb_size','100'),(16,0,'thumb_crop','1'),(17,0,'thumb_crop_width','85'),(18,0,'thumb_crop_height','85'),(19,0,'thumb_sharpen','0'),(20,0,'image_sharpen','0'),(21,0,'albums_per_page','5'),(22,0,'images_per_page','15'),(23,0,'gallery_password',NULL),(24,0,'gallery_hint',''),(25,0,'search_password',NULL),(26,0,'search_hint',''),(27,0,'gmaps_apikey',''),(28,0,'album_session','0'),(29,0,'perform_watermark','0'),(30,0,'watermark_h_offset','90'),(31,0,'watermark_w_offset','90'),(32,0,'watermark_image','watermarks/watermark.png'),(33,0,'watermark_scale','5'),(34,0,'watermark_allow_upscale','1'),(35,0,'perform_video_watermark','0'),(36,0,'video_watermark_image','watermarks/watermark-video.png'),(37,0,'spam_filter','none'),(38,0,'email_new_comments','1'),(39,0,'gallery_sorttype','ID'),(40,0,'gallery_sortdirection','0'),(41,0,'image_sorttype','Filename'),(42,0,'image_sortdirection','0'),(43,0,'hotlink_protection','1'),(44,0,'current_theme','default'),(45,0,'feed_items','10'),(46,0,'feed_imagesize','240'),(47,0,'search_fields','32767'),(48,0,'allowed_tags_default','a => (href => () title => ())\nabbr =>(title =>())\nacronym =>(title =>())\nb => ()\nblockquote =>(cite =>())\ncode => ()\nem => ()\ni => () \nstrike => ()\nstrong => ()\nul => ()\nol => ()\nli => ()\np => (style=>())\nh1=>(style=>())\nh2=>(style=>())\nh3=>(style=>())\nh4=>(style=>())\nh5=>(style=>())\nh6=>(style=>())\npre=>(style=>())\naddress=>(style=>())\nspan=>(style=>())\nimg=>(style=>() src=>() title=>() alt=>() width=>() height=>())\n'),(49,0,'allowed_tags','a => (href => () title => ())\r\nabbr =>(title =>())\r\nacronym =>(title =>())\r\nb => ()\r\nblockquote =>(cite =>())\r\ncode => ()\r\nem => ()\r\ni => () \r\nstrike => ()\r\nstrong => ()\r\nul => ()\r\nol => ()\r\nli => ()\r\np => (style=>())\r\nh1=>(style=>())\r\nh2=>(style=>())\r\nh3=>(style=>())\r\nh4=>(style=>())\r\nh5=>(style=>())\r\nh6=>(style=>())\r\npre=>(style=>())\r\naddress=>(style=>())\r\nspan=>(style=>())\r\nimg=>(style=>() src=>() title=>() alt=>() width=>() height=>())\r\n'),(50,0,'style_tags','abbr => (title => ())\nacronym => (title => ())\nb => ()\nem => ()\ni => () \nstrike => ()\nstrong => ()\n'),(51,0,'comment_name_required','1'),(52,0,'comment_email_required','1'),(53,0,'comment_web_required','0'),(54,0,'Use_Captcha',''),(55,0,'full_image_quality','75'),(56,0,'persistent_archive','0'),(57,0,'protect_full_image','Protected view'),(58,0,'date_format','%c'),(59,0,'zp_plugin_google_maps','1'),(60,0,'zp_plugin_rating','1'),(61,0,'zp_plugin_image_album_statistics','1'),(62,0,'zp_plugin_flowplayer','1'),(63,0,'zp_plugin_admin_toolbox','0'),(64,0,'zp_plugin_GoogleCheckout','0'),(65,0,'zp_plugin_class-textobject','0'),(66,0,'zp_plugin_contact_form','0'),(67,0,'zp_plugin_dynamic-locale','0'),(68,0,'zp_plugin_flv_playlist','0'),(69,0,'zp_plugin_flvplayer','0'),(70,0,'zp_plugin_paged_thumbs_nav','0'),(71,0,'zp_plugin_print_album_menu','0'),(72,0,'zp_plugin_register_user','0'),(73,0,'zp_plugin_shutterfly','0'),(74,0,'zp_plugin_slideshow','0'),(75,0,'zp_plugin_static_html_cache','0'),(76,0,'zp_plugin_tag_suggest','0'),(77,0,'zp_plugin_user_logout','0'),(78,0,'zp_plugin_viewer_size_image','0'),(79,0,'zp_plugin_zenPaypal','0'),(80,0,'use_lock_image','1'),(81,0,'gallery_user',''),(82,0,'search_user',''),(83,0,'album_use_new_image_date','0'),(84,0,'thumb_select_images','1'),(85,0,'Gallery_description','You can insert your Gallery description using on the Admin Options tab.'),(86,0,'multi_lingual','1'),(87,0,'login_user_field','1'),(88,0,'tagsort','0'),(89,0,'albumimagesort','ID'),(90,0,'albumimagedirection','DESC'),(91,0,'cache_full_image','0'),(92,0,'custom_index_page',''),(93,0,'picture_of_the_day','a:3:{s:3:\"day\";N;s:6:\"folder\";N;s:8:\"filename\";N;}'),(94,0,'exact_tag_match','0'),(95,0,'EXIFMake','1'),(96,0,'EXIFModel','1'),(97,0,'EXIFExposureTime','1'),(98,0,'EXIFFNumber','1'),(99,0,'EXIFFocalLength','1'),(100,0,'EXIFFocalLength35mm','1'),(101,0,'EXIFISOSpeedRatings','1'),(102,0,'EXIFDateTimeOriginal','1'),(103,0,'EXIFExposureBiasValue','1'),(104,0,'EXIFMeteringMode','1'),(105,0,'EXIFFlash','1'),(106,0,'EXIFOrientation','0'),(107,0,'EXIFImageWidth','0'),(108,0,'EXIFImageHeight','0'),(109,0,'EXIFContrast','0'),(110,0,'EXIFSharpness','0'),(111,0,'EXIFSaturation','0'),(112,0,'EXIFWhiteBalance','0'),(113,0,'EXIFSubjectDistance','0'),(114,0,'EXIFGPSLatitude','0'),(115,0,'EXIFGPSLatitudeRef','0'),(116,0,'EXIFGPSLongitude','0'),(117,0,'EXIFGPSLongitudeRef','0'),(118,0,'EXIFGPSAltitude','0'),(119,0,'EXIFGPSAltitudeRef','0'),(120,0,'user_registration_page',''),(121,0,'user_registration_text','Registro'),(122,0,'user_registration_tip','Haz clic aquÃ­ para registrarte en este sitio.'),(123,0,'auto_rotate','0'),(124,0,'admin_reset_date','1'),(125,0,'locale','en_US'),(126,0,'Allow_comments','1'),(127,0,'Allow_search','1'),(128,0,'Theme_colors','light'),(129,0,'flow_player_width','320'),(130,0,'flow_player_height','240'),(131,0,'flow_player_controlbarbackgroundcolor','0x567890'),(132,0,'flow_player_controlsareabordercolor','0x567890'),(133,0,'flow_player_autoplay',''),(134,0,'flow_player_backgroundcolor',''),(135,0,'gmaps_show_all_album_points','0'),(136,0,'gmaps_width','595'),(137,0,'gmaps_height','300'),(138,0,'zenphoto_captcha_lenght','5'),(139,0,'zenphoto_captcha_key','656b0ab5654af03bd52827c266158fb0'),(140,0,'zenphoto_captcha_string','abcdefghijkmnpqrstuvwxyz23456789ABCDEFGHJKLMNPQRSTUVWXYZ'),(141,0,'feed_sortorder','latest'),(142,0,'feed_enclosure','0'),(143,0,'feed_mediarss','0'),(144,0,'zp_plugin_class-video','1'),(145,0,'zp_plugin_filter-zenphoto_seo','1'),(146,0,'IPTC_encoding','ISO-8859-1'),(147,0,'UTF8_image_URI','0'),(148,0,'captcha','zenphoto'),(149,0,'sharpen_amount','40'),(150,0,'sharpen_radius','0.5'),(151,0,'sharpen_threshold','3'),(152,0,'gmaps_maptype_P','0'),(153,0,'gmaps_maptype_3D','0'),(154,0,'gmaps_maptype_map','1'),(155,0,'gmaps_maptype_hyb','1'),(156,0,'gmaps_maptype_sat','1'),(157,0,'gmaps_control_maptype','1'),(158,0,'gmaps_control','None'),(159,0,'gmaps_background',''),(160,0,'gmaps_starting_map','G_SATELLITE_MAP');
/*!40000 ALTER TABLE `znp_options` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `znp_tags`
--

DROP TABLE IF EXISTS `znp_tags`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `znp_tags` (
  `id` int(11) unsigned NOT NULL auto_increment,
  `name` varchar(255) collate utf8_unicode_ci default NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `name` (`name`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `znp_tags`
--

LOCK TABLES `znp_tags` WRITE;
/*!40000 ALTER TABLE `znp_tags` DISABLE KEYS */;
/*!40000 ALTER TABLE `znp_tags` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2009-05-12 18:08:00
